/****************************************************************************************/
/* This file:    QJPS_Figure_1_Replication.do					 				*/
/* Author:       Xiaobo Lu														*/ 
/* Date:         Dec. 2012														*/
/* Description:  Replicates Figure 1 in the paper							 	*/
/* Equality of Educational Opportunity and Attitudes toward Income Inequality: Evidence from China  */
/****************************************************************************************/

#delimit ;
clear;
set more off;
/* Insert the directory path in the following command */
* cd J:\Research\Papers\Ineq_Opp_Att_Ineq\QJPS\QJPS_Replication_Files;
cd $qjps/qjps_12043_supp_updated/;

log using QJPS_Figure_1_Replication.txt, text replace;

/* Obtain the average county-level responses on Attitudes toward Inequality and Belief of Equal Opportunity */
/* based on 10 multiple imputed dataset to address missing data problem */
/* Bulgaria (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==1, nsets(10);
/* Czech (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==13, nsets(10);
/* E. Germany (From 1991 ISJP Project)  */
misum ISJP ineq ineqopp if country==2, nsets(10);
/* Estonia (From 1991 ISJP Project)  */
misum ISJP ineq ineqopp if country==25, nsets(10);
/* Hungary (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==4, nsets(10);
/* Poland (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==8, nsets(10);
/* Russia (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==11, nsets(10);
/* Slovenia (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==12, nsets(10);
/* Japan (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==6, nsets(10);
/* Netherlands (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==7, nsets(10);
/* UK (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==9, nsets(10);
/* USA (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==10, nsets(10);
/* W. Germany (From 1991 ISJP Project) */
misum ISJP ineq ineqopp if country==3, nsets(10);
/* China (From 2004 China Survey) */
misum INEQCE ineq ineqopp, nsets(10);

/* Copy and Paste the values from above into a Stata data: Figure_1_data.dta */
use Figure_1_data.dta,clear;
scatter ineq ineqopp,mlabel(country) || lfit  ineq ineqopp, lpattern(dash) xtitle(Perception of Equal Opportunity) ytitle(Resentment toward Income Inequality) graphregion(fcolor(white)) legend(off);
graph export Figure_1.tif,replace;
log close;



