/****************************************************************************************/
/* This file:    QJPS_Main_Analysis_Replication.do				 				*/
/* Author:       Xiaobo Lu														*/ 
/* Date:         Dec. 2012														*/
/* Description:  Replicates all the main analyses in the following paper.		*/
/* Equality of Educational Opportunity and Attitudes toward Income Inequality: Evidence from China  */
/****************************************************************************************/

#delimit ;
clear;
set more off;
/* Insert the directory path in the following command */
cd J:\Research\Papers\Ineq_Opp_Att_Ineq\QJPS\QJPS_Replication_Files;

log using QJPS_Main_Analysis_Replication.txt, text replace;

/******************************/
/* Survey Experiment Evidence */
/******************************/

/*  Experiment 1   */
use Main_Survey_Experiment.dta,clear;


/* Table 1 Unequal Education Opportunity and Attitudes toward Inequality - Survey Experiment Evidence	*/
tabstat ineq_dm, by(treatment) stat(mean sd n max min);
tabstat ineq, by(treatment) stat(mean sd n max min);

/* Comparison between groups 1 & 2 */
ttest ineq_dm if treatment==1|treatment==2, by(treatment) unequal; 
ttest ineq if treatment==1|treatment==2, by(treatment) unequal; 

/* Comparison between groups 2 & 3*/
ttest ineq_dm if treatment==2|treatment==3, by(treatment) unequal;  
ttest ineq if treatment==2|treatment==3, by(treatment) unequal; 

/* Comparison between group 1 & 3*/
ttest ineq_dm if treatment==1|treatment==3, by(treatment) unequal; 
ttest ineq if treatment==1|treatment==3, by(treatment) unequal; 


/* Table 2 Regression Analysis for Survey Experiment			*/
gen treat1=1 if treatment==1;
replace treat1=0 if treat1==.;
gen treat2=1 if treatment==2;
replace treat2=0 if treat2==.;

oprobit ineq treat1 treat2,cluster(loc);
oprobit ineq treat1 treat2 male age edu log_income ,cluster(loc);
oprobit ineq treat1 treat2 male age edu log_income i.loc,cluster(loc);


/* Experiment 2 */

/* Table 3 Belief of Equal Education Opportunity - Survey Experiment Evidence */
use Second_Survey_Experiment.dta,clear;

tabstat equal_edu_opp_dm, by(treat) stat(mean sd n max min);
tabstat equal_edu_opp, by(treat) stat(mean sd n max min);

ttest equal_edu_opp_dm,by(treat) unequal;
ttest equal_edu_opp,by(treat) unequal;



/*****************************/
/* Quasi-RD Analysis Results */
/*****************************/

clear;

/* Table 4 The Effects of Expansion of College Enrollment in China in 1999*/
/* The between group mean difference is calculated after obtaining the mean and standard errors for each group */
/* Panel 1: 18-year-olds in 1999 as the Threshold */
misum INEQCE ineq_dmy if treat18_2==1, nsets(10);
misum INEQCE ineq_dmy if treat18_2==0, nsets(10);

misum INEQCE ineq if treat18_2==1, nsets(10);
misum INEQCE ineq if treat18_2==0, nsets(10);


/* Panel 2: 19-year-olds in 1999 as the Threshold */

misum INEQCE ineq_dmy if treat19_2==1, nsets(10);
misum INEQCE ineq_dmy if treat19_2==0, nsets(10);

misum INEQCE ineq if treat19_2==1, nsets(10);
misum INEQCE ineq if treat19_2==0, nsets(10);

/* Table 5 Ordered Probit Analysis of College Expansion in China */
/* 18-year-olds in 1999 as the Threshold  */
miest INEQCE oprobit ineq treat18_2,robust nsets(10);
miest INEQCE oprobit ineq treat18_2 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat18_3,robust nsets(10);
miest INEQCE oprobit ineq treat18_3 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat18,robust nsets(10);
miest INEQCE oprobit ineq treat18 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);

/* 19-year-olds in 1999 as the Threshold */
miest INEQCE oprobit ineq treat19_2,robust nsets(10);
miest INEQCE oprobit ineq treat19_2 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat19_3,robust nsets(10);
miest INEQCE oprobit ineq treat19_3 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat19,robust nsets(10);
miest INEQCE oprobit ineq treat19 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);


/* Table 6  Robustness Check (Falsification Test) */
/* 16-year-olds in 1999 as the Threshold  */
miest INEQCE oprobit ineq treat16_2,robust nsets(10);
miest INEQCE oprobit ineq treat16_2 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat16_3,robust nsets(10);
miest INEQCE oprobit ineq treat16_3 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);

/* 17-year-olds in 1999 as the Threshold  */
miest INEQCE oprobit ineq treat17_2,robust nsets(10);
miest INEQCE oprobit ineq treat17_2 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat17_3,robust nsets(10);
miest INEQCE oprobit ineq treat17_3 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);

/* 20-year-olds in 1999 as the Threshold  */
miest INEQCE oprobit ineq treat20_2,robust nsets(10);
miest INEQCE oprobit ineq treat20_2 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat20_3,robust nsets(10);
miest INEQCE oprobit ineq treat20_3 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);

/* 21-year-olds in 1999 as the Threshold  */
miest INEQCE oprobit ineq treat21_2,robust nsets(10);
miest INEQCE oprobit ineq treat21_2 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);
miest INEQCE oprobit ineq treat21_3,robust nsets(10);
miest INEQCE oprobit ineq treat21_3 male edu married ptymem log_famttincome hukou empstus, robust nsets(10);

/* Table 7 Matching Analysis of College Expansion in China  */
/* "miest" command cannot combine with "pscore" and "attr" commands in Stata. In the following commands */
/* I first analyze each dataset using "pscore" and "attr." I then comebine the estimation results from */
/* dataset by following King et al. 2001. I combine the results in a seperate Excel file QJPS_Tables_of_Results_Final.xlsx, under the Table_7_data workshet */
/* The overall point estimate is simply the average of the m separate estimates */
/* The variance of the multiple imputation point estimate is the average of the */
/* estimated variances from within each completed data set, plus the sample     */
/* variance in the point estimates across the data sets (multiplied by a factor */
/* that corrects for bias because m is smaller than infinity)                   */
/* King, Gary, James Honaker, Anne Joseph, and Kenneth Scheve. 2001. Analyzing Incomplete Political Science Data: An Alternative Algorithm for Multiple Imputation. American Political Science Review 95 (1):49-69. */


use INEQCE1,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE2,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE3,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE4,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE5,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE6,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE7,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE8,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE9,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);


use INEQCE10,clear;
/*  18-year-olds in 1999 as the Threshold */
pscore treat18_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_2);
attr ineq treat18_2,pscore(propensity18_2) comsup  boot rep(100);
pscore treat18_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity18_3);
attr ineq treat18_3,pscore(propensity18_3) comsup  boot rep(100);

/*  19-year-olds in 1999 as the Threshold */
pscore treat19_2 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_2);
attr ineq treat19_2,pscore(propensity19_2) comsup  boot rep(100);
pscore treat19_3 hukou male married ptymem log_famttincome empstus edu, pscore(propensity19_3);
attr ineq treat19_3,pscore(propensity19_3) comsup  boot rep(100);

log close;



