/****************************************************************************************/
/* This file:    QJPS_Online_Appendix_Analysis_Replication.do	 				*/
/* Author:       Xiaobo Lu														*/ 
/* Date:         Dec. 2012														*/
/* Description:  Replicates all the supplement analyses reported in the Online Appendix Tables */
/* Equality of Educational Opportunity and Attitudes toward Income Inequality: Evidence from China  */
/****************************************************************************************/

#delimit ;
clear;
set more off;
/* Insert the directory path in the following command */
* cd J:\Research\Papers\Ineq_Opp_Att_Ineq\QJPS\QJPS_Replication_Files;
cd $qjps/qjps_12043_supp_updated/;
capture log close;
log using QJPS_Online_Appendix_Analysis_Replication.txt, text replace;

/* Table A1 Equality of Opportunity and Individual Attitudes toward Income Inequality: Cross-Country Evidence */
/* Pool all */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc cty*,robust nsets(10);
/* Bulgaria */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==1,robust nsets(10);
/* Czech */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==13,robust nsets(10);
/* E. Germany	 */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==2,robust nsets(10);
/* Estonia */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==25,robust nsets(10);
/* Hungary */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==4,robust nsets(10);
/* Poland */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==8,robust nsets(10);
/* Russia */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==11,robust nsets(10);
/* Slovenia */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==12,robust nsets(10);
/* Japan */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==6,robust nsets(10);
/* Netherlands */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==7,robust nsets(10);
/* UK */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==9,robust nsets(10);
/* USA */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==10,robust nsets(10);
/* W. Germany */
miest ISJP oprobit ineq ineqopp male age edu married log_hhinc if country==3,robust nsets(10);


/* Table A2 Analysis of 2004 Chinese National Survey */
miest INEQCE oprobit ineq ineqopp male edu age married log_famttincome , robust nsets(10);
miest INEQCE oprobit ineq ineqopp male edu age married log_famttincome hukou ptymem, robust nsets(10);

/* Table A3: Summary Statistics for Control Variables in the 2009 China Experiment */ 
use Main_Survey_Experiment.dta,clear;

ttest male if treatment==1 | treatment==2, by(treatment);
ttest male if treatment==1 | treatment==3, by(treatment);
ttest male if treatment==2 | treatment==3, by(treatment);


/* edu */
ttest edu if treatment==1 | treatment==2, by(treatment);
ttest edu if treatment==1 | treatment==3, by(treatment);
ttest edu if treatment==2 | treatment==3, by(treatment);


/* birth year */
ttest age if treatment==1 | treatment==2, by(treatment);
ttest age if treatment==1 | treatment==3, by(treatment);
ttest age if treatment==2 | treatment==3, by(treatment);


/* individal income group */
ttest log_income if treatment==1 | treatment==2, by(treatment);
ttest log_income if treatment==1 | treatment==3, by(treatment);
ttest log_income if treatment==2 | treatment==3, by(treatment);


/* Table A4 Survey Experiment 2 (Belief of Equality of Opportunity)	 */
use Second_Survey_Experiment.dta,clear;

oprobit equal_edu_opp treat, cluster(loc) ;
oprobit equal_edu_opp treat male age edu income_hh, cluster(loc);
oprobit equal_edu_opp treat male age edu income_hh i.loc, cluster(loc);


/* Table A5 Summary Statistics for Group Characteristics in the Quasi-regression discontinuity Analysis */
/* Panel 1 18-year-olds in 1999 as the Threshold */
/* The between group mean difference is calculated after obtaining the mean and standard errors for each group */

misum INEQCE hukou if treat18_2==1, nsets(10);
misum INEQCE hukou if treat18_2==0, nsets(10);

misum INEQCE male if treat18_2==1, nsets(10);
misum INEQCE male if treat18_2==0, nsets(10);

misum INEQCE edu if treat18_2==1, nsets(10);
misum INEQCE edu if treat18_2==0, nsets(10);

misum INEQCE married if treat18_2==1, nsets(10);
misum INEQCE married if treat18_2==0, nsets(10);

misum INEQCE ptymem if treat18_2==1, nsets(10);
misum INEQCE ptymem if treat18_2==0, nsets(10);

misum INEQCE log_famttincome if treat18_2==1, nsets(10);
misum INEQCE log_famttincome if treat18_2==0, nsets(10);

misum INEQCE empstus if treat18_2==1, nsets(10);
misum INEQCE empstus if treat18_2==0, nsets(10);

/* Panel 2 19-year-olds in 1999 as the Threshold */
/* The between group mean difference is calculated after obtaining the mean and standard errors for each group */

misum INEQCE hukou if treat19_2==1, nsets(10);
misum INEQCE hukou if treat19_2==0, nsets(10);

misum INEQCE male if treat19_2==1, nsets(10);
misum INEQCE male if treat19_2==0, nsets(10);

misum INEQCE edu if treat19_2==1, nsets(10);
misum INEQCE edu if treat19_2==0, nsets(10);

misum INEQCE married if treat19_2==1, nsets(10);
misum INEQCE married if treat19_2==0, nsets(10);

misum INEQCE ptymem if treat19_2==1, nsets(10);
misum INEQCE ptymem if treat19_2==0, nsets(10);

misum INEQCE log_famttincome if treat19_2==1, nsets(10);
misum INEQCE log_famttincome if treat19_2==0, nsets(10);

misum INEQCE empstus if treat19_2==1, nsets(10);
misum INEQCE empstus if treat19_2==0, nsets(10);

log close;




